import {
  Component,
  createEffect,
  createResource,
  createSignal,
  For,
  onCleanup,
  Suspense,
} from 'solid-js';

import OlMap from 'ol/Map';

import dispatch, { cancelDispatch } from '../../workers/dispatcher-main';
import getUri from '../../lib/ids';

import Trkseg from '../trkseg';
import VectorSource from 'ol/source/Vector';

interface Props {
  trkId: string;
  vectorSource: VectorSource;
  context: any;
}
export const Trk: Component<Props> = ({ vectorSource, trkId, context }) => {
  const [trk, setTrk] = createSignal<Trk>();
  const [dispatchId, setDispatchId] = createSignal<number>(-1);

  const trkCallBack = (error: any, result: any, id?: number) => {
    if (error) {
      console.error({ caller: 'trkCallBack', error });
    } else {
      console.log({ caller: 'trkCallBack', result });
      setTrk(result);
    }
    if (id) {
      setDispatchId(id);
    }
  };

  dispatch(
    {
      action: 'getAndWatch',
      params: {
        id: trkId,
        method: 'getTrk',
      },
    },
    trkCallBack,
    true
  );

  onCleanup(() => {
    dispatch({
      action: 'cancelWatch',
      params: {
        id: trkId,
        method: 'getTrk',
      },
    });
    cancelDispatch(dispatchId());
  });

  createEffect(() => {
    console.log({ caller: 'Trk', vectorSource, trkId, trk: trk() });
  });

  return (
    // @ts-ignore
    <For each={trk() ? trk().trkseg || [] : []}>
      {(trksegId: string) => {
        console.log({ caller: 'Trk / loop', trksegId });
        return (
          <Suspense>
            <Trkseg
              vectorSource={vectorSource}
              trksegId={trksegId}
              context={{ ...context, trk, trkId }}
            />
          </Suspense>
        );
      }}
    </For>
  );
};

export default Trk;
